        SUBROUTINE SYMBEL(X,Y,DEGRES,HEIGHT,NCHAR,STRING)
C** 
C A simple forward to SYMBEL_HERSHEY.
C This was done to match PyFerret where the original 
C subroutine here was renamed SYMBEL_HERSHEY.
C**
C V7.22 *acm* 10/17 Fix ticket 2566: if zero or negative character size, exit.

C
C       CALL SYMBEL(X,Y,DEGRES,HEIGHT,NCHAR,STRING)
C
C       THIS SUBROUTINE DRAWS A STRING OF CHARACTERS.
C
C       THE VARIOUS PARAMETERS AND THEIR DEFINITIONS ARE LISTED
C       BELOW:
C        X,Y    - COORDINATES OF THE LOWER LEFT-HAND CORNER OF
C                 THE FIRST CHARACTER IN USERS UNITS.
C        DEGRES - ANGLE AT WHICH THE CHARACTERS ARE TO BE DRAWN
C                 IN DEGREES RELATIVE TO THE X-AXIS.
C        HEIGHT - HEIGHT OF THE CHARACTERS IN INCHES (OR MM).
C        NCHAR  - NUMBER OF CHARACTERS TO BE DRAWN.
C        STRING - ARRAY CONTAINING THE DISPLAY CODES OF THE
C                 CHARACTERS TO BE DRAWN.
C
        IF (height .LE. 0. ) RETURN
	CALL SYMBEL_HERSHEY(X,Y,DEGRES,HEIGHT,NCHAR,STRING)
        RETURN
        END

